Changelog 
==========

0.1.2 (2021-01-31)
------------------

- set error message correctly in relevant fields on form 
  validation failure


0.1.1 (2020-12-24)
------------------

- added `dc2esmapping` - converts dataclass to elasticsearch mapping
- default string length to 256
- index integer as long
- fix null format handling
- fix multi-session issue with formvalidators
- update timezone when reading data in ES Storage


0.1.0 (2020-11-13)
------------------

- Initial release


